@@ -5,7 +5,7 @@ use warnings;
 
 package Net::Fritz::Service;
 # ABSTRACT: represents a TR064 service
-$Net::Fritz::Service::VERSION = 'v0.0.4';
+$Net::Fritz::Service::VERSION = 'v0.0.5';
 
 use Digest::MD5 qw(md5_hex);
 use SOAP::Lite; # +trace => [ transport => sub { print $_[0]->as_string } ]; # TODO: remove
@@ -142,7 +142,7 @@ sub call {
 
     my @args;
     foreach my $arg (keys %call_args) {
-	push @args, SOAP::Data->name($arg)->value($call_args{$arg});
+	push @args, SOAP::Data->name($arg)->value($call_args{$arg})->type('string');
     }
 
     my $url = $self->fritz->upnp_url . $self->controlURL;
@@ -318,7 +318,7 @@ Net::Fritz::Service - represents a TR064 service
 
 =head1 VERSION
 
-version v0.0.4
+version v0.0.5
 
 =head1 SYNOPSIS
 
